@@ -1,4 +1,3 @@
-from .experimental import *  # noqa
 from .credentials import *  # noqa
 from .driver import *  # noqa
 from .table import *  # noqa
@@ -8,7 +7,6 @@ from .scheme import *  # noqa
 from .settings import *  # noqa
 from .resolver import *  # noqa
 from .export import *  # noqa
-from .s3list import *  # noqa
 from .auth_helpers import *  # noqa
 from .operation import *  # noqa
 from .scripting import *  # noqa
